@@ -1,4 +1,4 @@
-/* $Id: book.cc 1219 2006-06-14 16:54:38Z holger $
+/* $Id: book.cc 1393 2006-10-21 08:00:37Z holger $
  *
  * HoiChess/book.cc
  *
@@ -119,7 +119,9 @@ BookEntry BookEntry::h2b(const BookEntry& h, bool swap_byteorder)
 		BookEntry b;
 		b.hashkey = reverse_byte_order(h.hashkey);
 		for (unsigned int i=0; i<NR_MOVES; i++) {
+#ifdef HOICHESS	// FIXME for Xiangqi
 			b.move[i] = Move(reverse_byte_order(h.move[i]));
+#endif
 			b.count[i] = reverse_byte_order(h.count[i]);
 		}
 		return b;
@@ -272,6 +274,10 @@ Book::Book(const char * filename)
 				filename, 
 				(unsigned long) header.magic,
 				(unsigned long) BookHeader::s_magic);
+			fprintf(stderr,
+				"Maybe you are trying to use an opening book"
+				" for HoiChess with HoiXiangqi or"
+				" vice versa.\n");
 			fclose(fp);
 			throw BookException();
 		}
