@@ -1,4 +1,4 @@
-/* $Id: common.h 1236 2006-06-18 12:19:41Z holger $
+/* $Id: common.h 1350 2006-08-04 16:53:56Z holger $
  *
  * HoiChess/common.h
  *
@@ -26,7 +26,14 @@
 #include "version.h"
 #include "config.h"
 
-#define PROGNAME	"HoiChess"
+#if defined(HOICHESS)
+# define PROGNAME	"HoiChess"
+#elif defined(HOIXIANGQI)
+# define PROGNAME	"HoiXiangqi"
+#else
+# error "neither HOICHESS nor HOIXIANGQI is defined"
+#endif
+
 #define AUTHOR		"Holger Ruckdeschel"
 #define AUTHOR_EMAIL	"<holger@hoicher.de>"
 
@@ -79,13 +86,17 @@
 
 
 /*
- * Global variables, defined in main.cc
+ * Global variables
  */
 
+/* These are defined in main.cc */
 extern unsigned int debug;
 extern unsigned int verbose;
 extern bool ansicolor;
 
+/* This one is defined in uint64_table.cc */
+extern uint64_t uint64_table[];
+extern unsigned int uint64_table_size;
 
 
 /*
