@@ -1,4 +1,4 @@
-/* $Id: debug.cc 1227 2006-06-16 17:58:50Z holger $
+/* $Id: debug.cc 1350 2006-08-04 16:53:56Z holger $
  *
  * HoiChess/debug.cc
  *
@@ -39,6 +39,17 @@
 
 void __debug_helper::__dbg(unsigned int level, const char * fmt, ...)
 {
+	/* write message to logfile */
+	log("debug[%d]: %s:%d: %s: ", level, file, line, function);
+	va_list args;
+	va_start(args, fmt);
+	vlog(fmt, args);
+	va_end(args);
+	if (fmt[strlen(fmt)-1] != '\n') {
+		log("\n");
+	}
+
+	
 	if (debug < level) {
 		return;
 	}
@@ -47,13 +58,12 @@ void __debug_helper::__dbg(unsigned int level, const char * fmt, ...)
 		mutex->lock();
 	}
 	
-	fprintf(fp, "%s:%d: %s: debug(%d): ", file, line, function, level);
-
-	va_list args;
+	/* write message to fp */
+	fprintf(fp, "debug[%d]: %s:%d: %s: ", level, file, line, function);
+	//va_list args;
 	va_start(args, fmt);
 	vfprintf(fp, fmt, args);
 	va_end(args);
-
 	if (fmt[strlen(fmt)-1] != '\n') {
 		fprintf(fp, "\n");
 	}
@@ -65,17 +75,27 @@ void __debug_helper::__dbg(unsigned int level, const char * fmt, ...)
 
 void __debug_helper::__warn(const char * fmt, ...)
 {
+	/* write message to logfile */
+	log("warning: %s:%d: %s: ", file, line, function);
+	va_list args;
+	va_start(args, fmt);
+	vlog(fmt, args);
+	va_end(args);
+	if (fmt[strlen(fmt)-1] != '\n') {
+		log("\n");
+	}
+	
+	
 	if (mutex) {
 		mutex->lock();
 	}
 	
-	fprintf(fp, "%s:%d: %s: warning: ", file, line, function);
-
-	va_list args;
+	/* write message to fp */
+	fprintf(fp, "warning: %s:%d: %s: ", file, line, function);
+	//va_list args;
 	va_start(args, fmt);
 	vfprintf(fp, fmt, args);
 	va_end(args);
-
 	if (fmt[strlen(fmt)-1] != '\n') {
 		fprintf(fp, "\n");
 	}
@@ -87,17 +107,27 @@ void __debug_helper::__warn(const char * fmt, ...)
 
 void __debug_helper::__bug(const char * fmt, ...)
 {
+	/* write message to logfile */
+	log("bug: %s:%d: %s: ", file, line, function);
+	va_list args;
+	va_start(args, fmt);
+	vlog(fmt, args);
+	va_end(args);
+	if (fmt[strlen(fmt)-1] != '\n') {
+		log("\n");
+	}
+
+	
 	if (mutex) {
 		mutex->lock();
 	}
 
-	fprintf(fp, "%s:%d: %s: ", file, line, function);
-
-	va_list args;
+	/* write message to fp */
+	fprintf(fp, "bug: %s:%d: %s: ", file, line, function);
+	//va_list args;
 	va_start(args, fmt);
 	vfprintf(fp, fmt, args);
 	va_end(args);
-
 	if (fmt[strlen(fmt)-1] != '\n') {
 		fprintf(fp, "\n");
 	}
@@ -142,7 +172,9 @@ void debug_print_storagesizes()
 {
 	printf("Storage sizes:");
 
+#ifdef HOICHESS
 	PRNT(sizeof(Bitboard));
+#endif
 	PRNT(sizeof(Board));
 	PRNT(sizeof(Move));
 	PRNT(sizeof(Movelist));
