@@ -1,4 +1,4 @@
-/* $Id: pawnhash.h 1236 2006-06-18 12:19:41Z holger $
+/* $Id: pawnhash.h 1350 2006-08-04 16:53:56Z holger $
  *
  * HoiChess/pawnhash.h
  *
@@ -44,7 +44,9 @@ class PawnHashEntry
 	Hashkey hashkey;
 	int phase;
 	int score[2];
+#ifdef HOICHESS
 	Bitboard passed[2];
+#endif // HOICHESS
 
       public:
 	FORCEINLINE PawnHashEntry();
@@ -59,8 +61,10 @@ class PawnHashEntry
 	inline void set_phase(unsigned int phase);
 	inline int get_score(Color side) const;
 	inline void set_score(Color side, int score);
+#ifdef HOICHESS
 	inline Bitboard get_passed(Color side) const;
 	inline void set_passed(Color side, Bitboard bb);
+#endif // HOICHESS
 };
 
 inline PawnHashEntry::PawnHashEntry()
@@ -109,6 +113,7 @@ inline void PawnHashEntry::set_score(Color side, int score)
 	this->score[side] = score;
 }
 
+#ifdef HOICHESS
 inline Bitboard PawnHashEntry::get_passed(Color side) const
 {
 	return passed[side];
@@ -118,6 +123,7 @@ inline void PawnHashEntry::set_passed(Color side, Bitboard bb)
 {
 	this->passed[side] = bb;
 }
+#endif // HOICHESS
 
 /*****************************************************************************
  *
@@ -138,7 +144,7 @@ class PawnHashTable
 	unsigned long stat_hits;
 	unsigned long stat_hits2;
 	unsigned long stat_collisions;
-#endif
+#endif // COLLECT_STATISTICS
 
       public:
 	PawnHashTable(unsigned long size);
