@@ -1,8 +1,8 @@
-/* $Id: search.cc 1259 2006-07-02 17:49:55Z holger $
+/* $Id: search.cc 1381 2006-10-01 07:59:06Z holger $
  *
  * HoiChess/search.cc
  *
- * Copyright (C) 2004, 2005 Holger Ruckdeschel <holger@hoicher.de>
+ * Copyright (C) 2004-2006 Holger Ruckdeschel <holger@hoicher.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -47,7 +47,7 @@ Search::Search(Shell * shell)
 	
 	maxdepth = MAXDEPTH;
 
-	features = 0;
+	param_time = 0;
 	
 	thread = NULL;
 	stop = false;
@@ -233,13 +233,13 @@ void Search::main()
 		clock->allocate_time();
 
 		/* Extend search time when in check. */
-		if ((features & FEAT_TIME_IC) && rootboard.in_check()) {
+		if ((param_time & PARAM_TIME_IC) && rootboard.in_check()) {
 			clock->allocate_more_time("in check at root node");
 		}
 		
 		/* Extend search time when near book. */
 		unsigned int lbm = game->last_bookmove();
-		if ((features & FEAT_TIME_NB) && book != NULL
+		if ((param_time & PARAM_TIME_NB) && book != NULL
 				&& lbm > 0 && lbm <= 3) {
 			clock->allocate_more_time("near book");
 		}
@@ -305,7 +305,7 @@ void Search::iterate()
 
 			/* If a fail-low happens after we have searched for a
 			 * considerable amount of time, add some extra time. */
-			if ((features & FEAT_TIME_FL)
+			if ((param_time & PARAM_TIME_FL)
 					&& clock->get_elapsed_time()
 							> clock->get_limit()/2
 					&& mode == MOVE) {
@@ -328,7 +328,7 @@ void Search::iterate()
 
 			/* If a fail-high happens after we have searched for a
 			 * considerable amount of time, add some extra time. */
-			if ((features & FEAT_TIME_FH)
+			if ((param_time & PARAM_TIME_FH)
 					&& clock->get_elapsed_time()
 							> clock->get_limit()/2
 					&& mode == MOVE) {
@@ -358,7 +358,7 @@ int Search::search_root(unsigned int ply, int depth, int alpha, int beta)
 	ASSERT_DEBUG(tree.get_current_ply() == ply);
 	ASSERT_DEBUG(ply == 0);
 
-	DBG(1, "depth=%d, alpha=%d, beta=%d\n", depth, alpha, beta);
+//	DBG(3, "depth=%d, alpha=%d, beta=%d\n", depth, alpha, beta);
 	
 	Node * node = tree[ply];
 	
@@ -432,7 +432,7 @@ int Search::search_root(unsigned int ply, int depth, int alpha, int beta)
 		clear_line();
 	}
 
-	DBG(1, "return alpha=%d\n", alpha);
+//	DBG(3, "return alpha=%d\n", alpha);
 	return alpha;
 }
 
@@ -568,13 +568,16 @@ int Search::search(unsigned int ply, int depth, int alpha, int beta)
 		/* Futility pruning */
 		if (fprune && !node->in_check() && !cnode->in_check()
 				&& !mov.is_capture()
+#ifdef HOICHESS
 				&& !mov.is_enpassant()
-				&& !mov.is_promotion()) {
+				&& !mov.is_promotion()
+#endif // HOICHESS
+				) {
 			STAT_INC(stat_futcut);
 			tree.unmake_move();
 			continue;
 		}
-#endif
+#endif // USE_FUTILITYPRUNING
 		
 #ifdef USE_PVS
 		/* Search the current move. We use a standard
@@ -616,6 +619,7 @@ int Search::search(unsigned int ply, int depth, int alpha, int beta)
 	}
 
 	/* Test for checkmate or stalemate */
+#if defined(HOICHESS)
 	if (moves == 0) {
 		if (node->in_check()) {
 			alpha = -INFTY + ply;
@@ -623,6 +627,13 @@ int Search::search(unsigned int ply, int depth, int alpha, int beta)
 			alpha = DRAW;
 		}
 	}
+#elif defined(HOIXIANGQI)
+	if (moves == 0) {
+		alpha = -INFTY + ply;
+	}
+#else
+# error "neither HOICHESS nor HOIXIANGQI is defined"
+#endif
 
 	/* Save search result in hash table. */
 	if (hashtable && alpha > -MATE && alpha < MATE) {
@@ -640,19 +651,24 @@ int Search::search(unsigned int ply, int depth, int alpha, int beta)
 	}
 	
 #ifdef USE_HISTORY
-	/* Update history table */	
-	histtable[tree.get_board().get_side()]->add(node->get_best());
+	/* Update history table */
+	if (node->get_best()) {
+		histtable[tree.get_board().get_side()]->add(node->get_best());
+	}
 #endif
 
 #ifdef USE_KILLER
 	/* Update killer */
 	if (node->get_best() != node->get_hashmv()
-			&& !(node->get_best().flags() & MOVE_CAPTURE)
-			&& !(node->get_best().flags() & MOVE_ENPASSANT)
-			&& !(node->get_best().flags() & MOVE_PROMOTION)) {
+			&& !(node->get_best().is_capture())
+#ifdef HOICHESS
+			&& !(node->get_best().is_enpassant())
+			&& !(node->get_best().is_promotion())
+#endif // HOICHESS
+			) {
 		node->add_killer(node->get_best());
 	}
-#endif
+#endif // USE_KILLER
 
 #ifdef COLLECT_STATISTICS
 	stat_moves_sum += moves;
