@@ -1,8 +1,8 @@
-/* $Id: search.h 1259 2006-07-02 17:49:55Z holger $
+/* $Id: search.h 1381 2006-10-01 07:59:06Z holger $
  *
  * HoiChess/search.h
  *
- * Copyright (C) 2004, 2005 Holger Ruckdeschel <holger@hoicher.de>
+ * Copyright (C) 2004-2006 Holger Ruckdeschel <holger@hoicher.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -43,44 +43,53 @@ class Shell;
 class Search
 {
       public:
-	enum search_modes { MOVE, ANALYZE, PONDER };
-	enum features_e {
-		FEAT_TIME_FL = 0x01,
-		FEAT_TIME_IC = 0x02,
-		FEAT_TIME_NB = 0x04,
-		FEAT_TIME_FH = 0x08
+	enum search_modes_e { MOVE, ANALYZE, PONDER };
+	enum params_time_e {
+		PARAM_TIME_FL = 0x01,
+		PARAM_TIME_IC = 0x02,
+		PARAM_TIME_NB = 0x04,
+		PARAM_TIME_FH = 0x08
 	};
 		
       private:
 	Shell * shell;
 	
+	/* external data structures */
 	Evaluator * evaluator;
 	HashTable * hashtable;
 	HistoryTable * histtable[2];
 	Book * book;
 	
+	/* information about game */
 	const Game * game;
 	Clock * clock;
 
+	/* tree */
 	Tree tree;
 	int rootdepth;
 	int maxdepth;
 	
+	/* search mode */
 	int mode;
 	Color myside;
-	unsigned long features;
 	
+	/* parameters */
+	unsigned long param_time;
+	
+	/* thread/control stuff */
 	Mutex start_mutex;
 	Mutex main_mutex;
 	Thread * thread;
 	bool stop;
 	
+	/* required for time control and basic statistics */
 	unsigned long nodes;
 	unsigned long nodes_quiesce;
 	unsigned long next_timecheck;
 	unsigned long next_update;
 	
 #ifdef COLLECT_STATISTICS
+	/* extended statistics */
 	unsigned long stat_cut;
 	unsigned long stat_nullcut;
 	unsigned long stat_futcut;
@@ -92,12 +101,13 @@ class Search
 	unsigned long stat_moves_cnt_quiesce;
 #endif
 
-	/* Overall statistics */
+	/* overall statistics */
 	unsigned long ostat_knodes;
 	unsigned long ostat_csecs;
 	unsigned int  ostat_depth_sum;
 	unsigned int  ostat_depth_cnt;
-	
+
+	/* flags */
 	bool showthinking;
 	
       public:
@@ -119,8 +129,8 @@ class Search
 	void set_pawnhashtable(PawnHashTable * pawnhashtable);
 	void set_evalcache(EvaluationCache * evalcache);
 	void set_showthinking(bool x);
-	void set_features(unsigned long f);
-	unsigned long get_features() const;
+	Evaluator * get_evaluator() const;
+	void set_param(const std::string& name, const std::string& value);
 	
       private:
 	void main();
