@@ -1,4 +1,4 @@
-/* $Id: search_util.cc 1259 2006-07-02 17:49:55Z holger $
+/* $Id: search_util.cc 1379 2006-09-17 12:36:47Z holger $
  *
  * HoiChess/search_util.cc
  *
@@ -434,12 +434,21 @@ void Search::set_showthinking(bool x)
 	showthinking = x;
 }
 
-void Search::set_features(unsigned long f)
+Evaluator * Search::get_evaluator() const
 {
-	features = f;
+	return evaluator;
 }
 
-unsigned long Search::get_features() const
+void Search::set_param(const std::string& name, const std::string& value)
 {
-	return features;
+	if (name == "time") {
+		unsigned long v;
+		if (sscanf(value.c_str(), "%lx", &v) == 1) {
+			param_time = v;
+			printf("param_time = 0x%lx\n", param_time);
+		} else {
+			printf("Illegal argument for parameter '%s': '%s'\n",
+					name.c_str(), value.c_str());
+		}
+	}
 }
