@@ -1,4 +1,4 @@
-/* $Id: shell.cc 1230 2006-06-17 16:08:53Z holger $
+/* $Id: shell.cc 1350 2006-08-04 16:53:56Z holger $
  *
  * HoiChess/shell.cc
  *
@@ -43,6 +43,7 @@ Shell::Shell()
 	flag_ponder = false;
 	flag_showthinking = false;
 	flag_analyze = false;
+	flag_playboth = false;
 
 	script_it = script_lines.end();
 
@@ -85,11 +86,19 @@ void Shell::main()
 			/* let engine make a move */
 			engine_move();
 			continue;
+		} else if (flag_playboth) {
+			/* let engine make a move */
+			myside = game->get_side();
+			engine_move();
+			myside = NO_COLOR;
+			continue;
 		} else if (flag_ponder && !flag_force && game->is_running()) {
 			/* start search in background */
+			DBG(1, "starting background search...");
 			search->start_thread(*game, Search::PONDER, myside);
 		} else if (flag_analyze) {
 			/* start search in background */
+			DBG(1, "starting background search...");
 			search->start_thread(*game, Search::ANALYZE, NO_COLOR);
 		}
 
@@ -110,6 +119,8 @@ void Shell::interrupt()
 	}
 	search->interrupt();
 	stop = true;
+
+	flag_playboth = false;
 }
 
 /*
@@ -276,6 +287,10 @@ void Shell::input()
 {
 	cmd_args.clear();
 	
+	if (xboard) {
+		DBG(3, "waiting for input...");
+	}
+	
 	char * line = NULL;
 	if (script_it != script_lines.end()) {
 		line = get_line_script();
@@ -301,13 +316,15 @@ void Shell::input()
 		line[strlen(line)-1] = '\0';
 	}
 
+	DBG(1, "line = \"%s\"", line);
+
 	/* Tokenize the input. */
 	char * delim = " \t\n";
 	char * strtok_r_buf;
 	for (char * p = strtok_r(line, delim, &strtok_r_buf); 
 			p != NULL;
 			p = strtok_r(NULL, delim, &strtok_r_buf)) {
-		DBG(3, "p = \"%s\"", p);
+		//DBG(3, "p = \"%s\"", p);
 		cmd_args.push_back(p);
 	}
 
@@ -462,11 +479,17 @@ void Shell::user_move(Move mov)
 
 	if (!xboard) {
 		printf("\n");
-		game->get_board().print();
+		game->get_board().print(stdout, mov);
 		printf("\nYour move was: %s\n\n", san.c_str());
 	}
+	//game->get_board().print(stdout, mov);
 
-	print_result(game->get_result());
+	DBG(1, "user move: %s", san.c_str());
+
+	DBG(1, "result = %d", game->get_result());
+	if (game->get_result()) {
+		print_result();
+	}
 }
 
 void Shell::engine_move()
@@ -498,8 +521,10 @@ void Shell::engine_move()
 			BUG("book returned illegal move: %s",
 					mov.str().c_str());
 		}
-	} else {		
+	} else {
+		DBG(1, "starting search...");
 		search->start(*game, Search::MOVE, myside);
+		DBG(1, "search terminated");
 		mov = search->get_best();
 		bookmove = false;
 		if (!mov.is_valid(board)) {
@@ -522,38 +547,23 @@ void Shell::engine_move()
 		atomic_printf("move %s\n", str.c_str());
 	} else {
 		printf("\n");
-		game->get_board().print();
+		game->get_board().print(stdout, mov);
 		printf("\nMy move is: %s\n\n", san.c_str());
 	}
+	//game->get_board().print(stdout, mov);
+	
+	DBG(1, "engine move: %s", san.c_str());
 
-	print_result(game->get_result());
-}
-
-void Shell::print_result(int result) const
-{
-	switch (result) {
-	case Game::OPEN:
-		break;
-	case Game::WHITEMATES:
-		atomic_printf("1-0 {White mates}\n");
-		break;
-	case Game::BLACKMATES:
-		atomic_printf("0-1 {Black mates}\n");
-		break;
-	case Game::STALEMATE:
-		atomic_printf("1/2-1/2 {Stalemate}\n");
-		break;
-	case Game::RULE50:
-		atomic_printf("1/2-1/2 {50 move rule}\n");
-		break;
-	case Game::REPS3:
-		atomic_printf("1/2-1/2 {3 repetitions}\n");
-		break;
-	case Game::MATERIAL:
-		atomic_printf("1/2-1/2 {Insufficient material}\n");
-		break;
-	default:
-		BUG("illegal argument: %d", result);
+	DBG(1, "result = %d", game->get_result());
+	if (game->get_result()) {
+		print_result();
 	}
 }
 
+void Shell::print_result()
+{
+	atomic_printf("%s {%s}\n",
+			game->get_result_str().c_str(),
+			game->get_result_comment().c_str());
+}
+
