@@ -1,4 +1,4 @@
-/* $Id: shell_cmd.cc 1230 2006-06-17 16:08:53Z holger $
+/* $Id: shell_cmd.cc 1379 2006-09-17 12:36:47Z holger $
  *
  * HoiChess/shell_cmd.cc
  *
@@ -29,6 +29,8 @@
 #include <errno.h>
 #include <stdio.h>
 
+#include <sstream>
+
 struct Shell::command Shell::commands[] = {
 	/* xboard protocol commands */
 	{ "xboard",	&Shell::cmd_xboard,	false,	""	},
@@ -66,7 +68,7 @@ struct Shell::command Shell::commands[] = {
 	{ "nopost",	&Shell::cmd_nopost,	false,	"Hide thinking output" },
 	{ "analyze",	&Shell::cmd_analyze,	false,	"Enter analysis mode" },
 	{ "exit",	&Shell::cmd_exit,	false,	"Leave analysis mode" },
-	{ "name",	NULL,			false,	""	},
+	{ "name",	NULL,			true,	""	},
 	{ "rating",	NULL,			false,	""	},
 	{ "ics",	NULL,			false,	""	},
 	{ "computer",	NULL,			true,	""	},
@@ -91,6 +93,10 @@ struct Shell::command Shell::commands[] = {
 	{ "evalcache",	&Shell::cmd_evalcache,	false,	""	},
 	{ "set",	&Shell::cmd_set,	false,	""	},
 	{ "get",	&Shell::cmd_get,	false,	""	},
+	{ "playboth",	&Shell::cmd_playboth,	false,	""	},
+	{ "loadgame",	&Shell::cmd_loadgame,	false,	""	},
+	{ "savegame",	&Shell::cmd_savegame,	false,	""	},
+	{ "redo",	&Shell::cmd_redo,	false,	""	},
 	
 	{ NULL, NULL, false, NULL }
 };
@@ -115,18 +121,20 @@ void Shell::cmd_protover()
 {
 	CMD_REQUIRE_ARGS(1);
 
-	stdout_mutex.lock();
-	
-	printf("feature myname=\"%s\" variants=\"normal\"", myname.c_str());
-	printf(" ping=1 setboard=1 time=1 sigint=0 colors=0");
+	std::ostringstream ss;
+	ss << "feature";
+	ss << " myname=\"" << myname << "\"";
+	ss << " variants=\"normal\"";
+	ss << " ping=1 setboard=1 time=1 sigint=0 colors=0";
 #if defined(HAVE_PTHREAD) || defined(WIN32)
-	printf(" analyze=1");
+	ss << " analyze=1";
 #else
-	printf(" analyze=0");
+	ss << " analyze=0";
 #endif
-	printf(" done=1\n");
+	ss << " name=1";
+	ss << " done=1\n";
 
-	stdout_mutex.unlock();
+	atomic_printf("%s", ss.str().c_str());
 }
 
 void Shell::cmd_accepted()
@@ -302,7 +310,7 @@ void Shell::cmd_setboard()
 		return;
 	}
 	
-	print_result(game->get_result());
+	print_result();
 }
 
 void Shell::cmd_bk()
@@ -321,7 +329,15 @@ void Shell::cmd_bk()
 void Shell::cmd_undo()
 {
 	search->stop_thread();
-	game->undo_move();
+	if (cmd_args.size() == 2 && cmd_args[1] == "all") {
+		while (game->undo_move());		
+	} else {
+		if (!game->undo_move()) {
+			if (!xboard) {
+				printf("No move to be undone.\n");
+			}
+		}
+	}
 }
 
 void Shell::cmd_remove()
@@ -516,13 +532,16 @@ void Shell::cmd_show()
 		printf("[White]\n"); game->get_clock(WHITE).print();
 		printf("\n[Black]\n"); game->get_clock(BLACK).print();
 	} else if (param == "game") {
-		game->print();
+		game->print(stdout);
+	} else if (param == "pgn") {
+		game->write_pgn(stdout);
 	} else {
 		printf("Usage: show {board|fen}\n");
 		printf("       show {moves|captures|noncaptures|escapes}\n");
 		printf("       show eval\n");
 		printf("       show clocks\n");
 		printf("       show game\n");
+		printf("       show pgn\n");
 	}
 }
 
@@ -849,13 +868,19 @@ void Shell::cmd_set()
 		CMD_REQUIRE_ARGS(2);
 		set_myname(cmd_args[2].c_str());
 		printf("myname set to %s\n", cmd_args[2].c_str());
-	} else if (cmd_args[1] == "search_features") {
-		CMD_REQUIRE_ARGS(2);
-		unsigned long features;
-		if (sscanf(cmd_args[2].c_str(), "%lx", &features) == 1) {
-			search->set_features(features);
-			printf("search_features set to 0x%lx\n", features);
-		}
+	} else if (cmd_args[1] == "searchparam") {
+		CMD_REQUIRE_ARGS(3);
+		const std::string& name = cmd_args[2];
+		const std::string& value = cmd_args[3];
+		search->set_param(name, value);
+	} else if (cmd_args[1] == "evalparam") {
+		CMD_REQUIRE_ARGS(3);
+		const std::string& name = cmd_args[2];
+		const std::string& value = cmd_args[3];
+		search->get_evaluator()->set_param(name, value);
+	} else {
+		printf("Illegal argument to command 'set': '%s'\n",
+				cmd_args[1].c_str());
 	}
 }
 
@@ -865,8 +890,106 @@ void Shell::cmd_get()
 
 	if (cmd_args[1] == "myname") {
 		printf("myname = %s\n", myname.c_str());
-	} else if (cmd_args[1] == "search_features") {
-		unsigned long features = search->get_features();
-		printf("search_features = 0x%lx\n", features);
+#if 0
+	} else if (cmd_args[1] == "searchparam") {
+		//unsigned long features = search->get_features();
+		//printf("search_features = 0x%lx\n", features);
+#endif
+	} else {
+		printf("Illegal argument to command 'get': '%s'\n",
+				cmd_args[1].c_str());
+	}
+}
+
+void Shell::cmd_playboth()
+{
+	flag_playboth = !flag_playboth;
+}
+
+void Shell::cmd_loadgame()
+{
+	CMD_REQUIRE_ARGS(1);
+	const char * pgnfile  = cmd_args[1].c_str();
+
+	FILE* fp = fopen(pgnfile, "r");
+	if (fp == NULL) {
+		fprintf(stderr, "Cannot open %s for reading: %s\n",
+				pgnfile, strerror(errno));
+		return;
+	}
+
+	PGN pgn;
+	pgn.parse(fp);
+
+	fclose(fp);
+	
+	Game g(pgn.get_opening(), Clock(), Clock());
+	std::list<Move> moves = pgn.get_moves();
+	for (std::list<Move>::const_iterator 
+			it = moves.begin();
+			it != moves.end();
+			it++) {
+		GameEntry::MoveAttributes move_attr(false, false);
+		g.make_move(*it, move_attr);
+	}
+
+	printf("--- begin read game ---\n");
+	g.write_pgn(stdout);
+	printf("--- end read game ---\n");
+
+	search->stop_thread();
+	*game = g;
+}
+
+void Shell::cmd_savegame()
+{
+	CMD_REQUIRE_ARGS(1);
+	const char * pgnfile  = cmd_args[1].c_str();
+
+	FILE* fp = fopen(pgnfile, "w");
+	if (fp == NULL) {
+		fprintf(stderr, "Cannot open %s for writing: %s\n",
+				pgnfile, strerror(errno));
+		return;
+	}
+	
+	game->write_pgn(fp);
+	
+	fclose(fp);
+}
+
+void Shell::cmd_redo()
+{
+	search->stop_thread();
+	
+	Move mov;
+	if (cmd_args.size() == 2 && cmd_args[1] == "all") {
+		Move mov0;
+		do {
+			mov = mov0;
+			mov0 = game->redo_move();
+		} while (mov0);
+
+		if (!mov) {
+			if (!xboard) {
+				printf("No move to be redone.\n");
+			}
+			return;
+		}
+	} else {
+		mov = game->redo_move();
+		if (!mov) {
+			if (!xboard) {
+				printf("No move to be redone.\n");
+			}
+			return;
+		}
+	}
+
+	if (!xboard) {
+		game->get_board().print(stdout, mov);
+		if (game->get_result()) {
+			print_result();
+		}
 	}
 }
