@@ -1,4 +1,4 @@
-/* $Id: tree.cc 1223 2006-06-15 19:35:06Z holger $
+/* $Id: tree.cc 1350 2006-08-04 16:53:56Z holger $
  *
  * HoiChess/tree.cc
  *
@@ -31,6 +31,11 @@
  *
  *****************************************************************************/
 
+Node::Node()
+{
+	historytable = NULL;
+}
+
 Move Node::first()
 {
 	current_move_no = -1;
@@ -219,25 +224,30 @@ void Node::score_moves()
 			 * returned by pick(), thus we do not need to assign
 			 * any score to it. */
 			continue;
-		} else if ((mov.flags() & MOVE_CAPTURE)
-				|| (mov.flags() & MOVE_PROMOTION)
-				|| (mov.flags() & MOVE_ENPASSANT)) {
+		} else if (mov.is_capture()
+#ifdef HOICHESS
+				|| mov.is_promotion()
+				|| mov.is_enpassant()
+#endif
+				) {
 			/* TODO This could be improved I think */
 			score += 10000
 				+ mat_values[mov.cap_ptype()]
 				- mat_values[mov.ptype()];
-			if ((mov.flags() & MOVE_PROMOTION)) {
+#ifdef HOICHESS
+			if (mov.is_promotion()) {
 				score += mat_values[mov.promote_to()];
 			}
+#endif
 		} else {
 #ifdef USE_KILLER
-			/* TODO */
+			/* TODO This could be improved I think */
 			if (mov == killer1 || mov == killer2) {
 				score += 5000;
 			}
 #endif
 #ifdef USE_HISTORY
-			/* TODO */
+			/* TODO This could be improved I think */
 			if (historytable) {
 				score += historytable->get(mov);
 			}
